import ExtractTextPlugin from 'extract-text-webpack-plugin';
import path from 'path';
import webpack from 'webpack';
import { BundleAnalyzerPlugin } from 'webpack-bundle-analyzer';

import packageJson from './package.json';

const main = () => {
  const PROD = process.argv.includes('-p');
  const watching = process.argv.includes('--watch');
  const min = PROD ? '.min' : '';
  const entry = {};
  entry[packageJson.name] = './src/main.scss';
  entry['whatwg-fetch'] = './node_modules/whatwg-fetch/fetch.js';

  const filename = `[name]${min}.js`;
  const plugins = [new ExtractTextPlugin(`[name]${min}.css`)];

  if (PROD) {
    plugins.push(
      new webpack.optimize.UglifyJsPlugin({
        output: {
          comments: false,
        },
      })
    );
  }

  if (!watching) {
    plugins.push(new BundleAnalyzerPlugin({ analyzerMode: 'static' }));
  }

  return {
    entry,
    output: {
      filename,
      path: path.resolve(__dirname, 'dist'),
    },
    plugins,
    module: {
      rules: [
        {
          test: /\.js$/,
          use: [
            {
              loader: 'babel-loader',
              options: { presets: ['react', 'es2015', 'stage-1'] },
            },
          ],
        },
        {
          test: /\.scss$/,
          use: ExtractTextPlugin.extract({
            fallback: 'style-loader',
            use: ['css-loader', 'postcss-loader', 'sass-loader'],
          }),
        },
        {
          test: /\.(woff|woff2|eot|ttf|otf)$/,
          use: ['file-loader'],
        },
      ],
    },
    devtool: PROD ? false : 'source-maps',
    target: 'web',
  };
};

export default main;
